==> lemnisk_flutter-1.0.0.tar.gz: android/src/main/java/co/lemnisk/flutter_wrapper/FlutterWrapperPlugin.java <==
package co.lemnisk.flutter_wrapper;

import android.app.Activity;
import android.content.Context;
import android.util.Log;
import java.util.Map;

import androidx.annotation.NonNull;

import com.google.android.gms.tasks.OnSuccessListener;
import com.google.android.gms.tasks.Task;
import com.google.firebase.messaging.FirebaseMessaging;

import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.embedding.engine.plugins.activity.ActivityAware;
import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import co.lemnisk.app.android.AttributeBuilder;
import co.lemnisk.app.android.LemniskHelper;

/** FlutterWrapperPlugin */
public class FlutterWrapperPlugin implements FlutterPlugin, MethodCallHandler, ActivityAware {
  /// The MethodChannel that will the communication between Flutter and native Android
  ///
  /// This local reference serves to register the plugin with the Flutter Engine and unregister it
  /// when the Flutter Engine is detached from the Activity
  private MethodChannel channel;
  private Context context = null;
  private Activity currentActivity = null;

  @Override
  public void onAttachedToEngine(@NonNull FlutterPluginBinding flutterPluginBinding) {
    channel = new MethodChannel(flutterPluginBinding.getBinaryMessenger(), "flutter_wrapper");
    channel.setMethodCallHandler(this);
    context = flutterPluginBinding.getApplicationContext();
    LemniskHelper helper = LemniskHelper.getInstance(context);

    Task<String> task = FirebaseMessaging.getInstance().getToken();
    helper.init();
  }

  @Override
  public void onMethodCall(@NonNull MethodCall call, @NonNull Result result) {
    Map<String, Object> arguments = call.arguments(); 
    if (call.method.equals("getPlatformVersion")) {
      result.success("Android " + android.os.Build.VERSION.RELEASE);
    }
    else if(call.method.equals("track")){
      if(arguments != null){
        track((String) arguments.get("eventName"), (Map<String, Object>) arguments.get("properties"), (Map<String, Object>) arguments.get("otherIds"));
      }
    }
    else if(call.method.equals("screen")){
      if(arguments != null){
        screen((String) arguments.get("name"), (Map<String, Object>) arguments.get("properties"), (Map<String, Object>) arguments.get("otherIds"));
      }
    }
    else if(call.method.equals("identify")){
      if(arguments != null){
        identify((String) arguments.get("userId"), (Map<String, Object>) arguments.get("properties"), (Map<String, Object>) arguments.get("otherIds"));
      }
    }
    else if(call.method.equals("createLemniskEvent")){
      if(arguments != null){
        createLemniskEvent((String) arguments.get("name"), (Map<String, Object>) arguments.get("object"));
      }
    }
    else if(call.method.equals("registerForPush")){
      if(arguments != null){
        registerForPushNotifications((String) arguments.get("title"), (String) arguments.get("message"));
      }
    }
    else {
      result.notImplemented();
    }
  }

  private AttributeBuilder getAttributeBuilderFromMap(Map<String, Object> map){
    AttributeBuilder.Builder builder = new AttributeBuilder.Builder();
    for(Map.Entry<String, Object> entry: map.entrySet()){
      builder.addAttribute(entry.getKey(), entry.getValue().toString());
    }
    return builder.build();
  }

  private void track(String eventName, Map<String, Object> properties, Map<String, Object> otherIds){
    Log.d("Lemnisk: ", "eventLogging: track: ");
    Log.d("Lemnisk: ", "eventLogging: properties: " + properties.toString() + " otherIds: " + otherIds.toString());
     
    try {
        AttributeBuilder propertiesBuilder = getAttributeBuilderFromMap(properties);
        AttributeBuilder otherIdsBuilder = getAttributeBuilderFromMap(otherIds);
        LemniskHelper.getInstance(context).track(eventName,propertiesBuilder,otherIdsBuilder);
      }
      catch (Exception e) {
        Log.e("Lemnisk", "Exception in track event", e);
      }
  }

  private void screen(String name, Map<String, Object> properties, Map<String, Object> otherIds){
    Log.d("Lemnisk: ", "eventLogging: screen: ");
    Log.d("Lemnisk: ", "eventLogging: properties: " + properties.toString() + " otherIds: " + otherIds.toString());

    try {
      AttributeBuilder propertiesBuilder = getAttributeBuilderFromMap(properties);
      AttributeBuilder otherIdsBuilder = getAttributeBuilderFromMap(otherIds);
      LemniskHelper.getInstance(context).screen(name,propertiesBuilder,otherIdsBuilder);
    }
    catch (Exception e) {
      Log.e("Lemnisk", "Exception in screen event", e);
    }
  }

  private void identify(String userId, Map<String, Object> properties, Map<String, Object> otherIds){
    Log.d("Lemnisk: ", "eventLogging: identify: ");
    Log.d("Lemnisk: ", "eventLogging: properties: " + properties.toString() + " otherIds: " + otherIds.toString());

    try {
      AttributeBuilder propertiesBuilder = getAttributeBuilderFromMap(properties);
      AttributeBuilder otherIdsBuilder = getAttributeBuilderFromMap(otherIds);
      LemniskHelper.getInstance(context).identify(userId,propertiesBuilder,otherIdsBuilder);
    }
    catch (Exception e) {
      Log.e("Lemnisk", "Exception in identify event", e);
    }
  }

  public void createLemniskEvent(String name, Map<String, Object> object) {
    Log.d("Lemnisk: ", "eventLogging: name: " + name);
    Log.d("Lemnisk: ", "eventLogging: object: " + object.toString());
    try {
        AttributeBuilder propertiesBuilder = getAttributeBuilderFromMap(object);
        LemniskHelper.getInstance(context).logEvent(name, propertiesBuilder);
    } catch (Exception e) {
      Log.e("Lemnisk", "Exception in createLemniskEvent", e);
    }
  }

  private  void registerForPushNotifications( String title, String message){
    try{
      if(title != null && message != null){
        Log.d("Lemnisk: ", "registerForPushNotifications");
        LemniskHelper.getInstance(context).registerForPushNotifications(currentActivity, title, message);
      }
      else{
        Log.d("Lemnisk: ", "Default registerForPushNotifications");
        LemniskHelper.getInstance(context).registerForPushNotifications(currentActivity);
      }
    }
    catch (Exception e) {
      Log.e("Lemnisk", "Exception in registerForPushNotifications", e);
    }
  }


  @Override
  public void onDetachedFromEngine(@NonNull FlutterPluginBinding binding) {
    channel.setMethodCallHandler(null);
  }

  @Override
  public void onAttachedToActivity(@NonNull ActivityPluginBinding binding) {
    currentActivity = binding.getActivity();
  }

  @Override
  public void onDetachedFromActivityForConfigChanges() {
    //Not Yet Implemented
  }

  @Override
  public void onReattachedToActivityForConfigChanges(@NonNull ActivityPluginBinding binding) {
    //Not Yet Implemented
  }

  @Override
  public void onDetachedFromActivity() {
    currentActivity = null;
  }
}

==> lemnisk_flutter-1.0.1.tar.gz: android/src/main/java/co/lemnisk/flutter_wrapper/FlutterWrapperPlugin.java <==
package co.lemnisk.flutter_wrapper;

import android.app.Activity;
import android.content.Context;
import android.util.Log;
import android.webkit.WebView;

import java.util.Map;

import androidx.annotation.NonNull;

import com.google.android.gms.tasks.Task;
import com.google.firebase.messaging.FirebaseMessaging;


import org.json.JSONException;
import org.json.JSONObject;

import co.lemnisk.app.android.Utils;
import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.embedding.engine.plugins.activity.ActivityAware;
import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import co.lemnisk.app.android.AttributeBuilder;
import co.lemnisk.app.android.LemniskHelper;

/** FlutterWrapperPlugin */
public class FlutterWrapperPlugin implements FlutterPlugin, MethodCallHandler, ActivityAware {
  /// The MethodChannel that will the communication between Flutter and native Android
  ///
  /// This local reference serves to register the plugin with the Flutter Engine and unregister it
  /// when the Flutter Engine is detached from the Activity
  private MethodChannel channel;
  private Context context = null;
  private Activity currentActivity = null;

  @Override
  public void onAttachedToEngine(@NonNull FlutterPluginBinding flutterPluginBinding) {
    channel = new MethodChannel(flutterPluginBinding.getBinaryMessenger(), "flutter_wrapper");
    channel.setMethodCallHandler(this);
    context = flutterPluginBinding.getApplicationContext();
    LemniskHelper helper = LemniskHelper.getInstance(context);
    Task<String> task = FirebaseMessaging.getInstance().getToken();
    helper.init();
  }

  @Override
  public void onMethodCall(@NonNull MethodCall call, @NonNull Result result) {
    Map<String, Object> arguments = call.arguments(); 
    if (call.method.equals("getPlatformVersion")) {
      result.success("Android " + android.os.Build.VERSION.RELEASE);
    }
    else if(call.method.equals("track")){
      if(arguments != null){
        track((String) arguments.get("eventName"), (Map<String, Object>) arguments.get("properties"), (Map<String, Object>) arguments.get("otherIds"));
      }
    }
    else if(call.method.equals("screen")){
      if(arguments != null){
        screen((String) arguments.get("name"), (Map<String, Object>) arguments.get("properties"), (Map<String, Object>) arguments.get("otherIds"));
      }
    }
    else if(call.method.equals("identify")){
      if(arguments != null){
        identify((String) arguments.get("userId"), (Map<String, Object>) arguments.get("properties"), (Map<String, Object>) arguments.get("otherIds"));
      }
    }
    else if(call.method.equals("registerForPush")){
      if(arguments != null){
        registerForPushNotifications((String) arguments.get("title"), (String) arguments.get("message"));
      }
    }
    else if(call.method.equals("getCookieId")){
      result.success(Utils.getInstance(context).getAdvertisingId());
    }
    else {
      result.notImplemented();
    }
  }

  private AttributeBuilder getAttributeBuilderFromMap(Map<String, Object> map) {
    AttributeBuilder.Builder builder = new AttributeBuilder.Builder();
    for(Map.Entry<String, Object> entry: map.entrySet()){
      String value = entry.getValue().toString();
      if(entry.getValue() instanceof Map){
        JSONObject jsonObject = new JSONObject((Map) entry.getValue());
        builder.addAttribute(entry.getKey(), jsonObject);
      }
      else{
        builder.addAttribute(entry.getKey(), value);
      }
    }
    return builder.build();
  }

  private void track(String eventName, Map<String, Object> properties, Map<String, Object> otherIds){
    Log.d("Lemnisk: ", "eventLogging: track: ");
    Log.d("Lemnisk: ", "eventLogging: properties: " + properties.toString() + " otherIds: " + otherIds.toString());
     
    try {
        AttributeBuilder propertiesBuilder = getAttributeBuilderFromMap(properties);
        AttributeBuilder otherIdsBuilder = getAttributeBuilderFromMap(otherIds);
        LemniskHelper.getInstance(context).track(eventName,propertiesBuilder,otherIdsBuilder);
      }
      catch (Exception e) {
        Log.e("Lemnisk", "Exception in track event", e);
      }
  }

  private void screen(String name, Map<String, Object> properties, Map<String, Object> otherIds){
    Log.d("Lemnisk: ", "eventLogging: screen: ");
    Log.d("Lemnisk: ", "eventLogging: properties: " + properties.toString() + " otherIds: " + otherIds.toString());

    try {
      AttributeBuilder propertiesBuilder = getAttributeBuilderFromMap(properties);
      AttributeBuilder otherIdsBuilder = getAttributeBuilderFromMap(otherIds);
      LemniskHelper.getInstance(context).screen(name,propertiesBuilder,otherIdsBuilder);
    }
    catch (Exception e) {
      Log.e("Lemnisk", "Exception in screen event", e);
    }
  }

  private void identify(String userId, Map<String, Object> properties, Map<String, Object> otherIds){
    Log.d("Lemnisk: ", "eventLogging: identify: ");
    Log.d("Lemnisk: ", "eventLogging: properties: " + properties.toString() + " otherIds: " + otherIds.toString());

    try {
      AttributeBuilder propertiesBuilder = getAttributeBuilderFromMap(properties);
      AttributeBuilder otherIdsBuilder = getAttributeBuilderFromMap(otherIds);
      LemniskHelper.getInstance(context).identify(userId,propertiesBuilder,otherIdsBuilder);
    }
    catch (Exception e) {
      Log.e("Lemnisk", "Exception in identify event", e);
    }
  }

  private  void registerForPushNotifications( String title, String message){
    try{
      if(title != null && message != null){
        Log.d("Lemnisk: ", "registerForPushNotifications");
        LemniskHelper.getInstance(context).registerForPushNotifications(currentActivity, title, message);
      }
      else{
        Log.d("Lemnisk: ", "Default registerForPushNotifications");
        LemniskHelper.getInstance(context).registerForPushNotifications(currentActivity);
      }
    }
    catch (Exception e) {
      Log.e("Lemnisk", "Exception in registerForPushNotifications", e);
    }
  }


  @Override
  public void onDetachedFromEngine(@NonNull FlutterPluginBinding binding) {
    channel.setMethodCallHandler(null);
  }

  @Override
  public void onAttachedToActivity(@NonNull ActivityPluginBinding binding) {
    currentActivity = binding.getActivity();
  }

  @Override
  public void onDetachedFromActivityForConfigChanges() {
    //Not Yet Implemented
  }

  @Override
  public void onReattachedToActivityForConfigChanges(@NonNull ActivityPluginBinding binding) {
    //Not Yet Implemented
  }

  @Override
  public void onDetachedFromActivity() {
    currentActivity = null;
  }
}
